require 'test_plugin_helper'

class ForemanOscTest < ActiveSupport::TestCase
  setup do
    User.current = User.find_by_login 'admin'
    disable_orchestration
  end

  context 'HostParameterExtensions' do
    setup do
      @parent_hostgroup = FactoryGirl.create(:hostgroup, name: 'owens')
      @normal_hostgroup = FactoryGirl.create(:hostgroup, name: 'compute', parent: @parent_hostgroup)
      @rw_hostgroup = FactoryGirl.create(:hostgroup, name: 'rw', parent: @parent_hostgroup)
      @normal_host1 = FactoryGirl.create(:host, hostgroup: @normal_hostgroup)
      @normal_host2 = FactoryGirl.create(:host, hostgroup: @normal_hostgroup)
      @rw_host1 = FactoryGirl.create(:host, hostgroup: @rw_hostgroup)
      @rw_host2 = FactoryGirl.create(:host, hostgroup: @rw_hostgroup)
      @normal_parameter1 = FactoryGirl.create(:host_parameter, name: 'nfsroot_path', value: '/foo1', host: @normal_host1)
      @normal_parameter2 = FactoryGirl.create(:host_parameter, name: 'nfsroot_path', value: '/foo2', host: @normal_host2)
      @rw_parameter1 = FactoryGirl.create(:host_parameter, name: 'nfsroot_path', value: '/foo1', host: @rw_host1)
      @rw_parameter2 = FactoryGirl.create(:host_parameter, name: 'nfsroot_path', value: '/foo2', host: @rw_host2)
    end

    test 'verify fixtures' do
      assert_equal false, @normal_parameter1.rw_host_nfsroot_path?
      assert_equal false, @normal_parameter2.rw_host_nfsroot_path?
      assert_equal true, @rw_parameter1.rw_host_nfsroot_path?
      assert_equal true, @rw_parameter2.rw_host_nfsroot_path?
    end

    test 'rw_host_nfsroot_path? - false if not nfsroot_path' do
      param = FactoryGirl.build(:host_parameter, name: 'nfsroot_kernel_version', value: '2.6.32')
      assert_equal false, param.rw_host_nfsroot_path?
    end

    test 'rw_host_nfsroot_path? - false if not RW host' do
      host = FactoryGirl.create(:host, hostgroup: FactoryGirl.create(:hostgroup, name: 'foo'))
      param = FactoryGirl.build(:host_parameter, name: 'nfsroot_path', value: '/foo1', host: host)
      assert_equal false, param.rw_host_nfsroot_path?
    end

    test 'rw hosts valid when nfsroot_path is different' do
      assert_valid @rw_parameter1
      assert_valid @rw_parameter2
    end

    test 'rw hosts invalid when nfsroot_path is the same' do
      @rw_parameter1.value = '/foo1'
      @rw_parameter2.value = '/foo1'
      #puts "DEBUG"
      #puts @rw_parameter2.valid?
      refute_valid @rw_parameter2
      assert_includes @rw_parameter2.errors[:value], "should be unique for RW hosts"
    end

    test 'non-rw hosts are valid when nfsroot_path is different and the same' do
      assert_valid @normal_parameter1
      assert_valid @normal_parameter2
      @normal_parameter1.value = '/foo1'
      @normal_parameter2.value = '/foo1'
      assert_valid @normal_parameter1
      assert_valid @normal_parameter2
    end
  end

end
